# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.models.project_error import ProjectError


class TestProjectError(unittest.TestCase):
    """ ProjectError unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testProjectError(self):
        """
        Test ProjectError
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = swagger_client.models.project_error.ProjectError()
        pass


if __name__ == '__main__':
    unittest.main()
