# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ServerRunStatisticsData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start': 'str',
        'stop': 'str',
        'exit_code': 'int',
        'size': 'int',
        'stacktrace': 'str'
    }

    attribute_map = {
        'start': 'start',
        'stop': 'stop',
        'exit_code': 'exit_code',
        'size': 'size',
        'stacktrace': 'stacktrace'
    }

    def __init__(self, start=None, stop=None, exit_code=None, size=None, stacktrace=None):
        """
        ServerRunStatisticsData - a model defined in Swagger
        """

        self._start = None
        self._stop = None
        self._exit_code = None
        self._size = None
        self._stacktrace = None

        if start is not None:
          self.start = start
        if stop is not None:
          self.stop = stop
        if exit_code is not None:
          self.exit_code = exit_code
        if size is not None:
          self.size = size
        if stacktrace is not None:
          self.stacktrace = stacktrace

    @property
    def start(self):
        """
        Gets the start of this ServerRunStatisticsData.
        Server start.

        :return: The start of this ServerRunStatisticsData.
        :rtype: str
        """
        return self._start

    @start.setter
    def start(self, start):
        """
        Sets the start of this ServerRunStatisticsData.
        Server start.

        :param start: The start of this ServerRunStatisticsData.
        :type: str
        """

        self._start = start

    @property
    def stop(self):
        """
        Gets the stop of this ServerRunStatisticsData.
        Server stop.

        :return: The stop of this ServerRunStatisticsData.
        :rtype: str
        """
        return self._stop

    @stop.setter
    def stop(self, stop):
        """
        Sets the stop of this ServerRunStatisticsData.
        Server stop.

        :param stop: The stop of this ServerRunStatisticsData.
        :type: str
        """

        self._stop = stop

    @property
    def exit_code(self):
        """
        Gets the exit_code of this ServerRunStatisticsData.
        Server exit code.

        :return: The exit_code of this ServerRunStatisticsData.
        :rtype: int
        """
        return self._exit_code

    @exit_code.setter
    def exit_code(self, exit_code):
        """
        Sets the exit_code of this ServerRunStatisticsData.
        Server exit code.

        :param exit_code: The exit_code of this ServerRunStatisticsData.
        :type: int
        """

        self._exit_code = exit_code

    @property
    def size(self):
        """
        Gets the size of this ServerRunStatisticsData.
        Server size.

        :return: The size of this ServerRunStatisticsData.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this ServerRunStatisticsData.
        Server size.

        :param size: The size of this ServerRunStatisticsData.
        :type: int
        """

        self._size = size

    @property
    def stacktrace(self):
        """
        Gets the stacktrace of this ServerRunStatisticsData.
        Server stacktrace.

        :return: The stacktrace of this ServerRunStatisticsData.
        :rtype: str
        """
        return self._stacktrace

    @stacktrace.setter
    def stacktrace(self, stacktrace):
        """
        Sets the stacktrace of this ServerRunStatisticsData.
        Server stacktrace.

        :param stacktrace: The stacktrace of this ServerRunStatisticsData.
        :type: str
        """

        self._stacktrace = stacktrace

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerRunStatisticsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
