# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ServerSizeError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'id': 'list[str]',
        'name': 'list[str]',
        'cpu': 'list[str]',
        'memory': 'list[str]',
        'active': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'id': 'id',
        'name': 'name',
        'cpu': 'cpu',
        'memory': 'memory',
        'active': 'active'
    }

    def __init__(self, non_field_errors=None, id=None, name=None, cpu=None, memory=None, active=None):
        """
        ServerSizeError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._id = None
        self._name = None
        self._cpu = None
        self._memory = None
        self._active = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if cpu is not None:
          self.cpu = cpu
        if memory is not None:
          self.memory = memory
        if active is not None:
          self.active = active

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this ServerSizeError.
        Errors not connected to any field.

        :return: The non_field_errors of this ServerSizeError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this ServerSizeError.
        Errors not connected to any field.

        :param non_field_errors: The non_field_errors of this ServerSizeError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def id(self):
        """
        Gets the id of this ServerSizeError.
        Id field errors.

        :return: The id of this ServerSizeError.
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ServerSizeError.
        Id field errors.

        :param id: The id of this ServerSizeError.
        :type: list[str]
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ServerSizeError.
        Name field errors.

        :return: The name of this ServerSizeError.
        :rtype: list[str]
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ServerSizeError.
        Name field errors.

        :param name: The name of this ServerSizeError.
        :type: list[str]
        """

        self._name = name

    @property
    def cpu(self):
        """
        Gets the cpu of this ServerSizeError.
        CPU field errors.

        :return: The cpu of this ServerSizeError.
        :rtype: list[str]
        """
        return self._cpu

    @cpu.setter
    def cpu(self, cpu):
        """
        Sets the cpu of this ServerSizeError.
        CPU field errors.

        :param cpu: The cpu of this ServerSizeError.
        :type: list[str]
        """

        self._cpu = cpu

    @property
    def memory(self):
        """
        Gets the memory of this ServerSizeError.
        Memory field errors.

        :return: The memory of this ServerSizeError.
        :rtype: list[str]
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """
        Sets the memory of this ServerSizeError.
        Memory field errors.

        :param memory: The memory of this ServerSizeError.
        :type: list[str]
        """

        self._memory = memory

    @property
    def active(self):
        """
        Gets the active of this ServerSizeError.
        Active field errors.

        :return: The active of this ServerSizeError.
        :rtype: list[str]
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this ServerSizeError.
        Active field errors.

        :param active: The active of this ServerSizeError.
        :type: list[str]
        """

        self._active = active

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerSizeError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
