# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ProjectFileError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'id': 'list[str]',
        'project': 'list[str]',
        'file': 'list[str]',
        'content': 'list[str]',
        'name': 'list[str]',
        'path': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'id': 'id',
        'project': 'project',
        'file': 'file',
        'content': 'content',
        'name': 'name',
        'path': 'path'
    }

    def __init__(self, non_field_errors=None, id=None, project=None, file=None, content=None, name=None, path=None):
        """
        ProjectFileError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._id = None
        self._project = None
        self._file = None
        self._content = None
        self._name = None
        self._path = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if id is not None:
          self.id = id
        if project is not None:
          self.project = project
        if file is not None:
          self.file = file
        if content is not None:
          self.content = content
        if name is not None:
          self.name = name
        if path is not None:
          self.path = path

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this ProjectFileError.
        Errors not connected to any field

        :return: The non_field_errors of this ProjectFileError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this ProjectFileError.
        Errors not connected to any field

        :param non_field_errors: The non_field_errors of this ProjectFileError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def id(self):
        """
        Gets the id of this ProjectFileError.
        id field errors

        :return: The id of this ProjectFileError.
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ProjectFileError.
        id field errors

        :param id: The id of this ProjectFileError.
        :type: list[str]
        """

        self._id = id

    @property
    def project(self):
        """
        Gets the project of this ProjectFileError.
        project field errors

        :return: The project of this ProjectFileError.
        :rtype: list[str]
        """
        return self._project

    @project.setter
    def project(self, project):
        """
        Sets the project of this ProjectFileError.
        project field errors

        :param project: The project of this ProjectFileError.
        :type: list[str]
        """

        self._project = project

    @property
    def file(self):
        """
        Gets the file of this ProjectFileError.
        file field errors

        :return: The file of this ProjectFileError.
        :rtype: list[str]
        """
        return self._file

    @file.setter
    def file(self, file):
        """
        Sets the file of this ProjectFileError.
        file field errors

        :param file: The file of this ProjectFileError.
        :type: list[str]
        """

        self._file = file

    @property
    def content(self):
        """
        Gets the content of this ProjectFileError.
        base64_data field errors

        :return: The content of this ProjectFileError.
        :rtype: list[str]
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this ProjectFileError.
        base64_data field errors

        :param content: The content of this ProjectFileError.
        :type: list[str]
        """

        self._content = content

    @property
    def name(self):
        """
        Gets the name of this ProjectFileError.
        name field errors

        :return: The name of this ProjectFileError.
        :rtype: list[str]
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ProjectFileError.
        name field errors

        :param name: The name of this ProjectFileError.
        :type: list[str]
        """

        self._name = name

    @property
    def path(self):
        """
        Gets the path of this ProjectFileError.
        path field errors

        :return: The path of this ProjectFileError.
        :rtype: list[str]
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this ProjectFileError.
        path field errors

        :param path: The path of this ProjectFileError.
        :type: list[str]
        """

        self._path = path

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ProjectFileError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
