# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.auth_api import AuthApi


class TestAuthApi(unittest.TestCase):
    """ AuthApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.auth_api.AuthApi()

    def tearDown(self):
        pass

    def test_auth_jwt_token_auth(self):
        """
        Test case for auth_jwt_token_auth

        Create JSON Web Token (JWT)
        """
        pass

    def test_auth_jwt_token_refresh(self):
        """
        Test case for auth_jwt_token_refresh

        Refresh a JSON Web Token (JWT)
        """
        pass

    def test_auth_jwt_token_verify(self):
        """
        Test case for auth_jwt_token_verify

        Validate JSON Web Token (JWT)
        """
        pass

    def test_auth_register(self):
        """
        Test case for auth_register

        Register a user
        """
        pass

    def test_oauth_login(self):
        """
        Test case for oauth_login

        
        """
        pass


if __name__ == '__main__':
    unittest.main()
