# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class DockerHost(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'ip': 'str',
        'port': 'int',
        'status': 'str',
        'owner': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'ip': 'ip',
        'port': 'port',
        'status': 'status',
        'owner': 'owner'
    }

    def __init__(self, id=None, name=None, ip=None, port=None, status=None, owner=None):
        """
        DockerHost - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._ip = None
        self._port = None
        self._status = None
        self._owner = None

        if id is not None:
          self.id = id
        self.name = name
        self.ip = ip
        if port is not None:
          self.port = port
        if status is not None:
          self.status = status
        if owner is not None:
          self.owner = owner

    @property
    def id(self):
        """
        Gets the id of this DockerHost.
        Unique identifier for docker host as UUID.

        :return: The id of this DockerHost.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DockerHost.
        Unique identifier for docker host as UUID.

        :param id: The id of this DockerHost.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DockerHost.
        Docker host name.

        :return: The name of this DockerHost.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DockerHost.
        Docker host name.

        :param name: The name of this DockerHost.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def ip(self):
        """
        Gets the ip of this DockerHost.
        Docker host IPv4 address

        :return: The ip of this DockerHost.
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """
        Sets the ip of this DockerHost.
        Docker host IPv4 address

        :param ip: The ip of this DockerHost.
        :type: str
        """
        if ip is None:
            raise ValueError("Invalid value for `ip`, must not be `None`")

        self._ip = ip

    @property
    def port(self):
        """
        Gets the port of this DockerHost.
        Docker host port.

        :return: The port of this DockerHost.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this DockerHost.
        Docker host port.

        :param port: The port of this DockerHost.
        :type: int
        """

        self._port = port

    @property
    def status(self):
        """
        Gets the status of this DockerHost.
        Docker host status.

        :return: The status of this DockerHost.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DockerHost.
        Docker host status.

        :param status: The status of this DockerHost.
        :type: str
        """

        self._status = status

    @property
    def owner(self):
        """
        Gets the owner of this DockerHost.
        UUID of Docker host owner.

        :return: The owner of this DockerHost.
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this DockerHost.
        UUID of Docker host owner.

        :param owner: The owner of this DockerHost.
        :type: str
        """

        self._owner = owner

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DockerHost):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
