# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ServerError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'id': 'list[str]',
        'name': 'list[str]',
        'created_at': 'list[str]',
        'image_name': 'list[str]',
        'server_size': 'list[str]',
        'startup_script': 'list[str]',
        'config': 'list[str]',
        'status': 'list[str]',
        'connected': 'list[str]',
        'host': 'list[str]',
        'endpoint': 'list[str]',
        'logs_url': 'list[str]',
        'status_url': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'id': 'id',
        'name': 'name',
        'created_at': 'created_at',
        'image_name': 'image_name',
        'server_size': 'server_size',
        'startup_script': 'startup_script',
        'config': 'config',
        'status': 'status',
        'connected': 'connected',
        'host': 'host',
        'endpoint': 'endpoint',
        'logs_url': 'logs_url',
        'status_url': 'status_url'
    }

    def __init__(self, non_field_errors=None, id=None, name=None, created_at=None, image_name=None, server_size=None, startup_script=None, config=None, status=None, connected=None, host=None, endpoint=None, logs_url=None, status_url=None):
        """
        ServerError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._id = None
        self._name = None
        self._created_at = None
        self._image_name = None
        self._server_size = None
        self._startup_script = None
        self._config = None
        self._status = None
        self._connected = None
        self._host = None
        self._endpoint = None
        self._logs_url = None
        self._status_url = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if created_at is not None:
          self.created_at = created_at
        if image_name is not None:
          self.image_name = image_name
        if server_size is not None:
          self.server_size = server_size
        if startup_script is not None:
          self.startup_script = startup_script
        if config is not None:
          self.config = config
        if status is not None:
          self.status = status
        if connected is not None:
          self.connected = connected
        if host is not None:
          self.host = host
        if endpoint is not None:
          self.endpoint = endpoint
        if logs_url is not None:
          self.logs_url = logs_url
        if status_url is not None:
          self.status_url = status_url

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this ServerError.
        Errors not connected to any field.

        :return: The non_field_errors of this ServerError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this ServerError.
        Errors not connected to any field.

        :param non_field_errors: The non_field_errors of this ServerError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def id(self):
        """
        Gets the id of this ServerError.
        id field errors.

        :return: The id of this ServerError.
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ServerError.
        id field errors.

        :param id: The id of this ServerError.
        :type: list[str]
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ServerError.
        name field errors.

        :return: The name of this ServerError.
        :rtype: list[str]
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ServerError.
        name field errors.

        :param name: The name of this ServerError.
        :type: list[str]
        """

        self._name = name

    @property
    def created_at(self):
        """
        Gets the created_at of this ServerError.
        created_at field errors.

        :return: The created_at of this ServerError.
        :rtype: list[str]
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this ServerError.
        created_at field errors.

        :param created_at: The created_at of this ServerError.
        :type: list[str]
        """

        self._created_at = created_at

    @property
    def image_name(self):
        """
        Gets the image_name of this ServerError.
        image_name field errors.

        :return: The image_name of this ServerError.
        :rtype: list[str]
        """
        return self._image_name

    @image_name.setter
    def image_name(self, image_name):
        """
        Sets the image_name of this ServerError.
        image_name field errors.

        :param image_name: The image_name of this ServerError.
        :type: list[str]
        """

        self._image_name = image_name

    @property
    def server_size(self):
        """
        Gets the server_size of this ServerError.
        server_size field errors.

        :return: The server_size of this ServerError.
        :rtype: list[str]
        """
        return self._server_size

    @server_size.setter
    def server_size(self, server_size):
        """
        Sets the server_size of this ServerError.
        server_size field errors.

        :param server_size: The server_size of this ServerError.
        :type: list[str]
        """

        self._server_size = server_size

    @property
    def startup_script(self):
        """
        Gets the startup_script of this ServerError.
        startup_script field errors.

        :return: The startup_script of this ServerError.
        :rtype: list[str]
        """
        return self._startup_script

    @startup_script.setter
    def startup_script(self, startup_script):
        """
        Sets the startup_script of this ServerError.
        startup_script field errors.

        :param startup_script: The startup_script of this ServerError.
        :type: list[str]
        """

        self._startup_script = startup_script

    @property
    def config(self):
        """
        Gets the config of this ServerError.
        config field errors.

        :return: The config of this ServerError.
        :rtype: list[str]
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this ServerError.
        config field errors.

        :param config: The config of this ServerError.
        :type: list[str]
        """

        self._config = config

    @property
    def status(self):
        """
        Gets the status of this ServerError.
        status field errors.

        :return: The status of this ServerError.
        :rtype: list[str]
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ServerError.
        status field errors.

        :param status: The status of this ServerError.
        :type: list[str]
        """

        self._status = status

    @property
    def connected(self):
        """
        Gets the connected of this ServerError.
        connected field errors.

        :return: The connected of this ServerError.
        :rtype: list[str]
        """
        return self._connected

    @connected.setter
    def connected(self, connected):
        """
        Sets the connected of this ServerError.
        connected field errors.

        :param connected: The connected of this ServerError.
        :type: list[str]
        """

        self._connected = connected

    @property
    def host(self):
        """
        Gets the host of this ServerError.
        host field errors.

        :return: The host of this ServerError.
        :rtype: list[str]
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this ServerError.
        host field errors.

        :param host: The host of this ServerError.
        :type: list[str]
        """

        self._host = host

    @property
    def endpoint(self):
        """
        Gets the endpoint of this ServerError.
        endpoint field errors.

        :return: The endpoint of this ServerError.
        :rtype: list[str]
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this ServerError.
        endpoint field errors.

        :param endpoint: The endpoint of this ServerError.
        :type: list[str]
        """

        self._endpoint = endpoint

    @property
    def logs_url(self):
        """
        Gets the logs_url of this ServerError.
        logs_url field errors.

        :return: The logs_url of this ServerError.
        :rtype: list[str]
        """
        return self._logs_url

    @logs_url.setter
    def logs_url(self, logs_url):
        """
        Sets the logs_url of this ServerError.
        logs_url field errors.

        :param logs_url: The logs_url of this ServerError.
        :type: list[str]
        """

        self._logs_url = logs_url

    @property
    def status_url(self):
        """
        Gets the status_url of this ServerError.
        status_url field errors.

        :return: The status_url of this ServerError.
        :rtype: list[str]
        """
        return self._status_url

    @status_url.setter
    def status_url(self, status_url):
        """
        Sets the status_url of this ServerError.
        status_url field errors.

        :param status_url: The status_url of this ServerError.
        :type: list[str]
        """

        self._status_url = status_url

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
