# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.notifications_api import NotificationsApi


class TestNotificationsApi(unittest.TestCase):
    """ NotificationsApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.notifications_api.NotificationsApi()

    def tearDown(self):
        pass

    def test_notification_read(self):
        """
        Test case for notification_read

        Retrieve a specific notification.
        """
        pass

    def test_notification_settings_create(self):
        """
        Test case for notification_settings_create

        Create global notification settings
        """
        pass

    def test_notification_settings_entity_create(self):
        """
        Test case for notification_settings_entity_create

        Create global notification settings
        """
        pass

    def test_notification_settings_entity_read(self):
        """
        Test case for notification_settings_entity_read

        Retrieve global notification settings for the authenticated user
        """
        pass

    def test_notification_settings_entity_update(self):
        """
        Test case for notification_settings_entity_update

        Modify global notification settings.
        """
        pass

    def test_notification_settings_read(self):
        """
        Test case for notification_settings_read

        Retrieve global notification settings for the authenticated user
        """
        pass

    def test_notification_settings_update(self):
        """
        Test case for notification_settings_update

        Modify global notification settings.
        """
        pass

    def test_notification_update(self):
        """
        Test case for notification_update

        Mark a specific notification as either read or unread.
        """
        pass

    def test_notifications_list(self):
        """
        Test case for notifications_list

        Get notifications of all types and entities for the authenticated user.
        """
        pass

    def test_notifications_list_entity(self):
        """
        Test case for notifications_list_entity

        Get notifications of all types and entities for the authenticated user.
        """
        pass

    def test_notifications_update_entity_list(self):
        """
        Test case for notifications_update_entity_list

        Mark a list of notifications as either read or unread.
        """
        pass

    def test_notifications_update_list(self):
        """
        Test case for notifications_update_list

        Mark a list of notifications as either read or unread.
        """
        pass


if __name__ == '__main__':
    unittest.main()
