# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class CardError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'name': 'list[str]',
        'address_line1': 'list[str]',
        'address_line2': 'list[str]',
        'address_city': 'list[str]',
        'address_state': 'list[str]',
        'address_zip': 'list[str]',
        'address_country': 'list[str]',
        'exp_month': 'list[str]',
        'exp_year': 'list[str]',
        'token': 'list[str]',
        'id': 'list[str]',
        'customer': 'list[str]',
        'address_line1_check': 'list[str]',
        'address_zip_check': 'list[str]',
        'brand': 'list[str]',
        'cvc_check': 'list[str]',
        'last4': 'list[str]',
        'fingerprint': 'list[str]',
        'funding': 'list[str]',
        'stripe_id': 'list[str]',
        'created': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'name': 'name',
        'address_line1': 'address_line1',
        'address_line2': 'address_line2',
        'address_city': 'address_city',
        'address_state': 'address_state',
        'address_zip': 'address_zip',
        'address_country': 'address_country',
        'exp_month': 'exp_month',
        'exp_year': 'exp_year',
        'token': 'token',
        'id': 'id',
        'customer': 'customer',
        'address_line1_check': 'address_line1_check',
        'address_zip_check': 'address_zip_check',
        'brand': 'brand',
        'cvc_check': 'cvc_check',
        'last4': 'last4',
        'fingerprint': 'fingerprint',
        'funding': 'funding',
        'stripe_id': 'stripe_id',
        'created': 'created'
    }

    def __init__(self, non_field_errors=None, name=None, address_line1=None, address_line2=None, address_city=None, address_state=None, address_zip=None, address_country=None, exp_month=None, exp_year=None, token=None, id=None, customer=None, address_line1_check=None, address_zip_check=None, brand=None, cvc_check=None, last4=None, fingerprint=None, funding=None, stripe_id=None, created=None):
        """
        CardError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._name = None
        self._address_line1 = None
        self._address_line2 = None
        self._address_city = None
        self._address_state = None
        self._address_zip = None
        self._address_country = None
        self._exp_month = None
        self._exp_year = None
        self._token = None
        self._id = None
        self._customer = None
        self._address_line1_check = None
        self._address_zip_check = None
        self._brand = None
        self._cvc_check = None
        self._last4 = None
        self._fingerprint = None
        self._funding = None
        self._stripe_id = None
        self._created = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if name is not None:
          self.name = name
        if address_line1 is not None:
          self.address_line1 = address_line1
        if address_line2 is not None:
          self.address_line2 = address_line2
        if address_city is not None:
          self.address_city = address_city
        if address_state is not None:
          self.address_state = address_state
        if address_zip is not None:
          self.address_zip = address_zip
        if address_country is not None:
          self.address_country = address_country
        if exp_month is not None:
          self.exp_month = exp_month
        if exp_year is not None:
          self.exp_year = exp_year
        if token is not None:
          self.token = token
        if id is not None:
          self.id = id
        if customer is not None:
          self.customer = customer
        if address_line1_check is not None:
          self.address_line1_check = address_line1_check
        if address_zip_check is not None:
          self.address_zip_check = address_zip_check
        if brand is not None:
          self.brand = brand
        if cvc_check is not None:
          self.cvc_check = cvc_check
        if last4 is not None:
          self.last4 = last4
        if fingerprint is not None:
          self.fingerprint = fingerprint
        if funding is not None:
          self.funding = funding
        if stripe_id is not None:
          self.stripe_id = stripe_id
        if created is not None:
          self.created = created

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this CardError.
        Errors not connected to any field

        :return: The non_field_errors of this CardError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this CardError.
        Errors not connected to any field

        :param non_field_errors: The non_field_errors of this CardError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def name(self):
        """
        Gets the name of this CardError.
        name field errors

        :return: The name of this CardError.
        :rtype: list[str]
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CardError.
        name field errors

        :param name: The name of this CardError.
        :type: list[str]
        """

        self._name = name

    @property
    def address_line1(self):
        """
        Gets the address_line1 of this CardError.
        address_line1 field errors

        :return: The address_line1 of this CardError.
        :rtype: list[str]
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """
        Sets the address_line1 of this CardError.
        address_line1 field errors

        :param address_line1: The address_line1 of this CardError.
        :type: list[str]
        """

        self._address_line1 = address_line1

    @property
    def address_line2(self):
        """
        Gets the address_line2 of this CardError.
        address_line2 field errors

        :return: The address_line2 of this CardError.
        :rtype: list[str]
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """
        Sets the address_line2 of this CardError.
        address_line2 field errors

        :param address_line2: The address_line2 of this CardError.
        :type: list[str]
        """

        self._address_line2 = address_line2

    @property
    def address_city(self):
        """
        Gets the address_city of this CardError.
        address_city field errors

        :return: The address_city of this CardError.
        :rtype: list[str]
        """
        return self._address_city

    @address_city.setter
    def address_city(self, address_city):
        """
        Sets the address_city of this CardError.
        address_city field errors

        :param address_city: The address_city of this CardError.
        :type: list[str]
        """

        self._address_city = address_city

    @property
    def address_state(self):
        """
        Gets the address_state of this CardError.
        address_state field errors

        :return: The address_state of this CardError.
        :rtype: list[str]
        """
        return self._address_state

    @address_state.setter
    def address_state(self, address_state):
        """
        Sets the address_state of this CardError.
        address_state field errors

        :param address_state: The address_state of this CardError.
        :type: list[str]
        """

        self._address_state = address_state

    @property
    def address_zip(self):
        """
        Gets the address_zip of this CardError.
        address_zip field errors

        :return: The address_zip of this CardError.
        :rtype: list[str]
        """
        return self._address_zip

    @address_zip.setter
    def address_zip(self, address_zip):
        """
        Sets the address_zip of this CardError.
        address_zip field errors

        :param address_zip: The address_zip of this CardError.
        :type: list[str]
        """

        self._address_zip = address_zip

    @property
    def address_country(self):
        """
        Gets the address_country of this CardError.
        address_country field errors

        :return: The address_country of this CardError.
        :rtype: list[str]
        """
        return self._address_country

    @address_country.setter
    def address_country(self, address_country):
        """
        Sets the address_country of this CardError.
        address_country field errors

        :param address_country: The address_country of this CardError.
        :type: list[str]
        """

        self._address_country = address_country

    @property
    def exp_month(self):
        """
        Gets the exp_month of this CardError.
        exp_month field errors

        :return: The exp_month of this CardError.
        :rtype: list[str]
        """
        return self._exp_month

    @exp_month.setter
    def exp_month(self, exp_month):
        """
        Sets the exp_month of this CardError.
        exp_month field errors

        :param exp_month: The exp_month of this CardError.
        :type: list[str]
        """

        self._exp_month = exp_month

    @property
    def exp_year(self):
        """
        Gets the exp_year of this CardError.
        exp_year field errors

        :return: The exp_year of this CardError.
        :rtype: list[str]
        """
        return self._exp_year

    @exp_year.setter
    def exp_year(self, exp_year):
        """
        Sets the exp_year of this CardError.
        exp_year field errors

        :param exp_year: The exp_year of this CardError.
        :type: list[str]
        """

        self._exp_year = exp_year

    @property
    def token(self):
        """
        Gets the token of this CardError.
        token field errors

        :return: The token of this CardError.
        :rtype: list[str]
        """
        return self._token

    @token.setter
    def token(self, token):
        """
        Sets the token of this CardError.
        token field errors

        :param token: The token of this CardError.
        :type: list[str]
        """

        self._token = token

    @property
    def id(self):
        """
        Gets the id of this CardError.
        id field errors

        :return: The id of this CardError.
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CardError.
        id field errors

        :param id: The id of this CardError.
        :type: list[str]
        """

        self._id = id

    @property
    def customer(self):
        """
        Gets the customer of this CardError.
        customer field errors

        :return: The customer of this CardError.
        :rtype: list[str]
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """
        Sets the customer of this CardError.
        customer field errors

        :param customer: The customer of this CardError.
        :type: list[str]
        """

        self._customer = customer

    @property
    def address_line1_check(self):
        """
        Gets the address_line1_check of this CardError.
        address_line1_check field errors

        :return: The address_line1_check of this CardError.
        :rtype: list[str]
        """
        return self._address_line1_check

    @address_line1_check.setter
    def address_line1_check(self, address_line1_check):
        """
        Sets the address_line1_check of this CardError.
        address_line1_check field errors

        :param address_line1_check: The address_line1_check of this CardError.
        :type: list[str]
        """

        self._address_line1_check = address_line1_check

    @property
    def address_zip_check(self):
        """
        Gets the address_zip_check of this CardError.
        address_zip_check field errors

        :return: The address_zip_check of this CardError.
        :rtype: list[str]
        """
        return self._address_zip_check

    @address_zip_check.setter
    def address_zip_check(self, address_zip_check):
        """
        Sets the address_zip_check of this CardError.
        address_zip_check field errors

        :param address_zip_check: The address_zip_check of this CardError.
        :type: list[str]
        """

        self._address_zip_check = address_zip_check

    @property
    def brand(self):
        """
        Gets the brand of this CardError.
        brand field errors

        :return: The brand of this CardError.
        :rtype: list[str]
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """
        Sets the brand of this CardError.
        brand field errors

        :param brand: The brand of this CardError.
        :type: list[str]
        """

        self._brand = brand

    @property
    def cvc_check(self):
        """
        Gets the cvc_check of this CardError.
        cvc_check field errors

        :return: The cvc_check of this CardError.
        :rtype: list[str]
        """
        return self._cvc_check

    @cvc_check.setter
    def cvc_check(self, cvc_check):
        """
        Sets the cvc_check of this CardError.
        cvc_check field errors

        :param cvc_check: The cvc_check of this CardError.
        :type: list[str]
        """

        self._cvc_check = cvc_check

    @property
    def last4(self):
        """
        Gets the last4 of this CardError.
        last4 field errors

        :return: The last4 of this CardError.
        :rtype: list[str]
        """
        return self._last4

    @last4.setter
    def last4(self, last4):
        """
        Sets the last4 of this CardError.
        last4 field errors

        :param last4: The last4 of this CardError.
        :type: list[str]
        """

        self._last4 = last4

    @property
    def fingerprint(self):
        """
        Gets the fingerprint of this CardError.
        fingerprint field errors

        :return: The fingerprint of this CardError.
        :rtype: list[str]
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """
        Sets the fingerprint of this CardError.
        fingerprint field errors

        :param fingerprint: The fingerprint of this CardError.
        :type: list[str]
        """

        self._fingerprint = fingerprint

    @property
    def funding(self):
        """
        Gets the funding of this CardError.
        funding field errors

        :return: The funding of this CardError.
        :rtype: list[str]
        """
        return self._funding

    @funding.setter
    def funding(self, funding):
        """
        Sets the funding of this CardError.
        funding field errors

        :param funding: The funding of this CardError.
        :type: list[str]
        """

        self._funding = funding

    @property
    def stripe_id(self):
        """
        Gets the stripe_id of this CardError.
        stripe_id field errors

        :return: The stripe_id of this CardError.
        :rtype: list[str]
        """
        return self._stripe_id

    @stripe_id.setter
    def stripe_id(self, stripe_id):
        """
        Sets the stripe_id of this CardError.
        stripe_id field errors

        :param stripe_id: The stripe_id of this CardError.
        :type: list[str]
        """

        self._stripe_id = stripe_id

    @property
    def created(self):
        """
        Gets the created of this CardError.
        created field errors

        :return: The created of this CardError.
        :rtype: list[str]
        """
        return self._created

    @created.setter
    def created(self, created):
        """
        Sets the created of this CardError.
        created field errors

        :param created: The created of this CardError.
        :type: list[str]
        """

        self._created = created

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CardError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
