# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.billing_api import BillingApi


class TestBillingApi(unittest.TestCase):
    """ BillingApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.billing_api.BillingApi()

    def tearDown(self):
        pass

    def test_billing_cards_create(self):
        """
        Test case for billing_cards_create

        Create new credit card
        """
        pass

    def test_billing_cards_delete(self):
        """
        Test case for billing_cards_delete

        Delete a credit card
        """
        pass

    def test_billing_cards_list(self):
        """
        Test case for billing_cards_list

        Get credit cards
        """
        pass

    def test_billing_cards_read(self):
        """
        Test case for billing_cards_read

        Get credit card by id
        """
        pass

    def test_billing_cards_replace(self):
        """
        Test case for billing_cards_replace

        Replace a credit card
        """
        pass

    def test_billing_cards_update(self):
        """
        Test case for billing_cards_update

        Update a credit card
        """
        pass

    def test_billing_invoice_items_list(self):
        """
        Test case for billing_invoice_items_list

        Get invoice items for a given invoice.
        """
        pass

    def test_billing_invoice_items_read(self):
        """
        Test case for billing_invoice_items_read

        Get a specific InvoiceItem.
        """
        pass

    def test_billing_invoices_list(self):
        """
        Test case for billing_invoices_list

        Get invoices
        """
        pass

    def test_billing_invoices_read(self):
        """
        Test case for billing_invoices_read

        Get an invoice
        """
        pass

    def test_billing_plans_list(self):
        """
        Test case for billing_plans_list

        Get billing plans
        """
        pass

    def test_billing_plans_read(self):
        """
        Test case for billing_plans_read

        Get a billing plan
        """
        pass

    def test_billing_subscriptions_create(self):
        """
        Test case for billing_subscriptions_create

        Create a new subscription
        """
        pass

    def test_billing_subscriptions_delete(self):
        """
        Test case for billing_subscriptions_delete

        Delete a subscription
        """
        pass

    def test_billing_subscriptions_list(self):
        """
        Test case for billing_subscriptions_list

        Get active subscriptons
        """
        pass

    def test_billing_subscriptions_read(self):
        """
        Test case for billing_subscriptions_read

        Get a subscriptions
        """
        pass


if __name__ == '__main__':
    unittest.main()
